@@ -1,13 +1,15 @@
-# Copyright 2018-2022 contributors to the OpenLineage project
+# Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 
-import os
+import json
 import logging
-from dateutil.parser import parse
-from jinja2 import Environment
+import os
+import uuid
 from typing import Any, Optional
 from urllib.parse import urlparse
 
+from dateutil.parser import parse
+from jinja2 import Environment
 
 log = logging.getLogger(__name__)
 
@@ -25,6 +27,15 @@ def is_datetime(result: Any):
     return "false"
 
 
+def is_uuid(result: Any):
+    try:
+        uuid.UUID(result)  # noqa
+        return "true"
+    except:  # noqa
+        pass
+    return "false"
+
+
 def env_var(var: str, default: Optional[str] = None) -> str:
     """The env_var() function. Return the environment variable named 'var'.
     If there is no such environment variable set, return the default.
@@ -58,6 +69,7 @@ def setup_jinja() -> Environment:
     env = Environment()
     env.globals['any'] = any
     env.globals['is_datetime'] = is_datetime
+    env.globals['is_uuid'] = is_uuid
     env.globals['env_var'] = env_var
     env.globals['not_match'] = not_match
     env.filters['url_scheme_authority'] = url_scheme_authority
@@ -76,10 +88,10 @@ def match(expected, result) -> bool:
         # Take a look only at keys present at expected dictionary
         for k, v in expected.items():
             if k not in result:
-                log.error(f"Key {k} not in event {result}\nExpected {expected}")
+                log.error(f"Key {k} not in received event {result}\nExpected {expected}")
                 return False
             if not match(v, result[k]):
-                log.error(f"For key {k}, value {v} not equals {result[k]}"
+                log.error(f"For key {k}, expected value {v} not equals received {result[k]}"
                           f"\nExpected {expected}, request {result}")
                 return False
     elif isinstance(expected, list):
@@ -110,7 +122,10 @@ def match(expected, result) -> bool:
                     return False
             else:
                 if not match(x, result[i]):
-                    log.error(f"List not matched expected: {x} result: {result[i]}")
+                    log.error(
+                        f"List not matched at {i}\n" +
+                        f"  expected:\n{json.dumps(x)}\n" +
+                        f"  result: \n{json.dumps(result[i])}")
                     return False
     elif isinstance(expected, str):
         if '{{' in expected:
